@@ -63,6 +63,12 @@ def register(group):
     help="Permit upgrade of function layers to new version.",
     is_flag=True,
 )
+@click.option(
+    "--enable-extension",
+    "-x",
+    help="Enable the New Relic Lambda Extension",
+    is_flag=True,
+)
 @click.pass_context
 def install(
     ctx,
@@ -74,6 +80,7 @@ def install(
     excludes,
     layer_arn,
     upgrade,
+    enable_extension,
 ):
     """Install New Relic AWS Lambda Layers"""
     session = boto3.Session(profile_name=aws_profile, region_name=aws_region)
@@ -92,6 +99,7 @@ def install(
                 layer_arn,
                 nr_account_id,
                 upgrade,
+                enable_extension,
                 ctx.obj["VERBOSE"],
             )
             for function in functions
@@ -100,6 +108,30 @@ def install(
 
     if install_success:
         done("Install Complete")
+        if ctx.obj["VERBOSE"]:
+            click.echo(
+                "\nNext step. Configure the CloudWatch subscription filter for your "
+                "Lambda functions with the below command:\n"
+            )
+            command = [
+                "$",
+                "newrelic-lambda",
+                "subscriptions",
+                "install",
+                "--function",
+                "all",
+            ]
+            if aws_profile:
+                command.append("--aws-profile %s" % aws_profile)
+            if aws_region:
+                command.append("--aws-region %s" % aws_region)
+            click.echo(" ".join(command))
+            click.echo(
+                "\nIf you used `--enable-logs` for the `newrelic-lambda integrations "
+                "install` command earlier, run this command instead:\n"
+            )
+            command.append('--filter-pattern ""')
+            click.echo(" ".join(command))
     else:
         failure("Install Incomplete. See messages above for details.", exit=True)
 
