@@ -8,6 +8,7 @@ import requests
 from newrelic_lambda_cli import utils
 from newrelic_lambda_cli.cliutils import failure, success
 from newrelic_lambda_cli.functions import get_function
+from newrelic_lambda_cli.integrations import get_license_key_policy_arn
 
 
 def index(region, runtime):
@@ -19,7 +20,9 @@ def index(region, runtime):
     return layers_response.get("Layers", [])
 
 
-def _add_new_relic(config, region, layer_arn, account_id, allow_upgrade):
+def _add_new_relic(
+    config, region, layer_arn, account_id, allow_upgrade, enable_extension
+):
     runtime = config["Configuration"]["Runtime"]
     if runtime not in utils.RUNTIME_CONFIG:
         failure(
@@ -30,13 +33,20 @@ def _add_new_relic(config, region, layer_arn, account_id, allow_upgrade):
 
     handler = config["Configuration"]["Handler"]
     runtime_handler = utils.RUNTIME_CONFIG.get(runtime, {}).get("Handler")
-    if not allow_upgrade and handler == runtime_handler:
+
+    existing_newrelic_layer = [
+        layer["Arn"]
+        for layer in config["Configuration"].get("Layers", [])
+        if layer["Arn"].startswith(utils.get_arn_prefix(region))
+    ]
+
+    if not allow_upgrade and existing_newrelic_layer:
         success(
             "Already installed on function '%s'. Pass --upgrade (or -u) to allow "
             "upgrade or reinstall to latest layer version."
             % config["Configuration"]["FunctionArn"]
         )
-        return False
+        return True
 
     existing_layers = [
         layer["Arn"]
@@ -45,6 +55,7 @@ def _add_new_relic(config, region, layer_arn, account_id, allow_upgrade):
     ]
 
     new_relic_layers = []
+
     if layer_arn:
         new_relic_layers = [layer_arn]
     else:
@@ -80,7 +91,6 @@ def _add_new_relic(config, region, layer_arn, account_id, allow_upgrade):
 
     update_kwargs = {
         "FunctionName": config["Configuration"]["FunctionArn"],
-        "Handler": runtime_handler,
         "Environment": {
             "Variables": config["Configuration"]
             .get("Environment", {})
@@ -89,17 +99,34 @@ def _add_new_relic(config, region, layer_arn, account_id, allow_upgrade):
         "Layers": new_relic_layers + existing_layers,
     }
 
+    # Only used by Python and Node.js runtimes
+    if runtime_handler:
+        update_kwargs["Handler"] = runtime_handler
+
     # Update the account id
     update_kwargs["Environment"]["Variables"]["NEW_RELIC_ACCOUNT_ID"] = str(account_id)
 
     # Update the NEW_RELIC_LAMBDA_HANDLER envvars only when it's a new install.
-    if handler != runtime_handler:
+    if runtime_handler and handler != runtime_handler:
         update_kwargs["Environment"]["Variables"]["NEW_RELIC_LAMBDA_HANDLER"] = handler
 
+    if enable_extension:
+        update_kwargs["Environment"]["Variables"][
+            "NEW_RELIC_LAMBDA_EXTENSION_ENABLED"
+        ] = "true"
+
     return update_kwargs
 
 
-def install(session, function_arn, layer_arn, account_id, allow_upgrade, verbose):
+def install(
+    session,
+    function_arn,
+    layer_arn,
+    account_id,
+    allow_upgrade,
+    enable_extension,
+    verbose,
+):
     client = session.client("lambda")
     config = get_function(session, function_arn)
     if not config:
@@ -108,7 +135,10 @@ def install(session, function_arn, layer_arn, account_id, allow_upgrade, verbose
 
     region = session.region_name
 
-    update_kwargs = _add_new_relic(config, region, layer_arn, account_id, allow_upgrade)
+    update_kwargs = _add_new_relic(
+        config, region, layer_arn, account_id, allow_upgrade, enable_extension
+    )
+
     if not update_kwargs:
         return False
 
@@ -121,6 +151,9 @@ def install(session, function_arn, layer_arn, account_id, allow_upgrade, verbose
         )
         return False
     else:
+        if enable_extension:
+            if not _attach_license_key_policy(session, config["Configuration"]["Role"]):
+                return False
         if verbose:
             click.echo(json.dumps(res, indent=2))
         success("Successfully installed layer on %s" % function_arn)
@@ -210,7 +243,44 @@ def uninstall(session, function_arn, verbose):
         )
         return False
     else:
+        _detach_license_key_policy(session, config["Configuration"]["Role"])
         if verbose:
             click.echo(json.dumps(res, indent=2))
         success("Successfully uninstalled layer on %s" % function_arn)
         return True
+
+
+def _attach_license_key_policy(session, role_arn):
+    """Attaches the license key secret policy to the specified role"""
+    policy_arn = get_license_key_policy_arn(session)
+    if not policy_arn:
+        failure(
+            "Could not find the New Relic license key secret policy. "
+            "Make sure you run 'newrelic-lambda integrations install' with "
+            "the '--enable-license-key-secret' flag."
+        )
+        return False
+    _, role_name = role_arn.rsplit("/", 1)
+    client = session.client("iam")
+    try:
+        client.attach_role_policy(RoleName=role_name, PolicyArn=policy_arn)
+    except botocore.exceptions.ClientError:
+        failure("Failed to attach %s policy to %s" % (policy_arn, role_arn))
+        return False
+    else:
+        return True
+
+
+def _detach_license_key_policy(session, role_arn):
+    """Detaches the license key secret policy from the specified role"""
+    policy_arn = get_license_key_policy_arn(session)
+    if not policy_arn:
+        return False
+    _, role_name = role_arn.rsplit("/", 1)
+    client = session.client("iam")
+    try:
+        client.detach_role_policy(RoleName=role_name, PolicyArn=policy_arn)
+    except botocore.exceptions.ClientError:
+        return False
+    else:
+        return True
